﻿using System;
using System.Collections.Generic;
using Alarus;
using Alarus.Config;
using Alarus.IpDevices;
using Alarus.IpDevices.Registration;
using Alarus.IpDevices.Util;
using Camera.Basic.Host;
using Camera.Basic.Log;
using Camera.Video;

namespace Camera
{
	public class ModuleInfo : IPlugin
	{
		public const string DeviceId = "33647867-33DA-4729-96B4-6D839AD73217";

		public const string DevBrandName = "Sample Brand";

		public const string DevName = "Sample Camera";

		public Guid Id => new Guid("D7E40264-D81A-4FAF-8B87-E48964398DF2");

		public string Name => DevBrandName;

		public string Manufacturer => "Example Company";

		public void Initialize(IPluginHost host)
		{
			SampleLogMgr.LogMgr = host.GetLogManager();
			HostFactory.SetFactory(host.CreatePluginHostFabric());

			var sampleDevice = new DevType_RegInfo
			{
				DeviceTypeGuid = new Guid(DeviceId),
				DevTypeModelName = DevName,
				DevTypeBrandName = DevBrandName,
				AvailableResolutions = new List<Resolution>
				{
					new Resolution(640, 480)
				},
				Capabilities = DevType_Capabilities.SupportsCameras,
				GetCameraService = (conParams, subParams) => new StreamReceiver(conParams, subParams),
				SetDeviceParameters = (conParams, subParams) => true
			};
			host.RegisterDevType(sampleDevice);

			var sampleDeviceMjpeg = new MediaStream_RegInfo
			{
				DeviceTypeGuid = new Guid(DeviceId),
				StreamFormat = VideoStreamFormats.MJPEG,
				ConnectionType = NetworkConnectionTypes.HTTP,
				Capabilities =
				{
					SupportedStreamTypes = ChannelStreamTypes.MainVideo,
					SupportedExtraParameters = new[] {DeviceParameters.Null, DeviceParameters.Null},
					SupportedDeviceParameters = new[] {DeviceParameters.Null, DeviceParameters.Null}
				}
			};
			host.RegisterMediaStreamInfo(sampleDeviceMjpeg);
		}
	}
}